(self.webpackChunkbqscales=self.webpackChunkbqscales||[]).push([[480],{480:function(e,r,t){"use strict";var n=this&&this.__createBinding||(Object.create?function(e,r,t,n){void 0===n&&(n=t),Object.defineProperty(e,n,{enumerable:!0,get:function(){return r[t]}})}:function(e,r,t,n){void 0===n&&(n=t),e[n]=r[t]}),o=this&&this.__setModuleDefault||(Object.create?function(e,r){Object.defineProperty(e,"default",{enumerable:!0,value:r})}:function(e,r){e.default=r}),a=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var r={};if(null!=e)for(var t in e)"default"!==t&&Object.hasOwnProperty.call(e,t)&&n(r,e,t);return o(r,e),r};Object.defineProperty(r,"__esModule",{value:!0});const l=t(871),c=a(t(811)),u=t(657),i={id:"bqscales:plugin",requires:[l.IJupyterWidgetRegistry],activate:function(e,r){r.registerWidget({name:u.MODULE_NAME,version:u.MODULE_VERSION,exports:c})},autoStart:!0};r.default=i},440:(e,r,t)=>{"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t(19);Object.defineProperty(r,"LinearScaleModel",{enumerable:!0,get:function(){return n.LinearScaleModel}});var o=t(10);Object.defineProperty(r,"LinearScale",{enumerable:!0,get:function(){return o.LinearScale}});var a=t(413);Object.defineProperty(r,"OrdinalScaleModel",{enumerable:!0,get:function(){return a.OrdinalScaleModel}});var l=t(291);Object.defineProperty(r,"OrdinalScale",{enumerable:!0,get:function(){return l.OrdinalScale}});var c=t(929);Object.defineProperty(r,"ColorScaleModel",{enumerable:!0,get:function(){return c.ColorScaleModel}});var u=t(94);Object.defineProperty(r,"ColorScale",{enumerable:!0,get:function(){return u.ColorScale}});var i=t(207);Object.defineProperty(r,"OrdinalColorScale",{enumerable:!0,get:function(){return i.OrdinalColorScale}});var d=t(137);Object.defineProperty(r,"OrdinalColorScaleModel",{enumerable:!0,get:function(){return d.OrdinalColorScaleModel}});var f=t(383);Object.defineProperty(r,"DateColorScaleModel",{enumerable:!0,get:function(){return f.DateColorScaleModel}});var b=t(884);Object.defineProperty(r,"DateColorScale",{enumerable:!0,get:function(){return b.DateColorScale}});var O=t(292);Object.defineProperty(r,"DateScaleModel",{enumerable:!0,get:function(){return O.DateScaleModel}});var g=t(900);Object.defineProperty(r,"DateScale",{enumerable:!0,get:function(){return g.DateScale}});var p=t(865);Object.defineProperty(r,"LogScaleModel",{enumerable:!0,get:function(){return p.LogScaleModel}});var s=t(287);Object.defineProperty(r,"LogScale",{enumerable:!0,get:function(){return s.LogScale}});var S=t(580);Object.defineProperty(r,"GeoScaleModel",{enumerable:!0,get:function(){return S.GeoScaleModel}}),Object.defineProperty(r,"MercatorModel",{enumerable:!0,get:function(){return S.MercatorModel}}),Object.defineProperty(r,"AlbersModel",{enumerable:!0,get:function(){return S.AlbersModel}}),Object.defineProperty(r,"AlbersUSAModel",{enumerable:!0,get:function(){return S.AlbersUSAModel}}),Object.defineProperty(r,"GnomonicModel",{enumerable:!0,get:function(){return S.GnomonicModel}}),Object.defineProperty(r,"OrthographicModel",{enumerable:!0,get:function(){return S.OrthographicModel}}),Object.defineProperty(r,"StereographicModel",{enumerable:!0,get:function(){return S.StereographicModel}}),Object.defineProperty(r,"EquiRectangularModel",{enumerable:!0,get:function(){return S.EquiRectangularModel}});var M=t(667);Object.defineProperty(r,"GeoScale",{enumerable:!0,get:function(){return M.GeoScale}}),Object.defineProperty(r,"Mercator",{enumerable:!0,get:function(){return M.Mercator}}),Object.defineProperty(r,"Albers",{enumerable:!0,get:function(){return M.Albers}}),Object.defineProperty(r,"AlbersUSA",{enumerable:!0,get:function(){return M.AlbersUSA}}),Object.defineProperty(r,"Gnomonic",{enumerable:!0,get:function(){return M.Gnomonic}}),Object.defineProperty(r,"Orthographic",{enumerable:!0,get:function(){return M.Orthographic}}),Object.defineProperty(r,"Stereographic",{enumerable:!0,get:function(){return M.Stereographic}}),Object.defineProperty(r,"EquiRectangular",{enumerable:!0,get:function(){return M.EquiRectangular}})},811:function(e,r,t){"use strict";var n=this&&this.__createBinding||(Object.create?function(e,r,t,n){void 0===n&&(n=t),Object.defineProperty(e,n,{enumerable:!0,get:function(){return r[t]}})}:function(e,r,t,n){void 0===n&&(n=t),e[n]=r[t]}),o=this&&this.__exportStar||function(e,r){for(var t in e)"default"===t||r.hasOwnProperty(t)||n(r,e,t)};Object.defineProperty(r,"__esModule",{value:!0}),o(t(440),r)}}]);